<?php
/**
 * The online photo albums plugin is a simple renderer plugin that allows
 * the easy insertion of online galleries such as picasa and flickr.
 * 
 * Thanks to the renderer guide by balupton, makers of the video_plugin
 * and the b2evolution guys.
 *
 * @author Brinley Ang {@link http://brinley.unbolt.net/}
 *
 * b2evolution - {@link http://b2evolution.net/}
 * Released under GNU GPL License - {@link http://b2evolution.net/about/license.html}
 * @copyright (c)2003-2005 by Francois PLANQUE - {@link http://fplanque.net/}
 */
if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

/**
 * Photoplug plugin
 *
 * @package plugins
 */
class photoplug_plugin extends Plugin
{
	var $code = 'photoplug_plugin';
	var $name = 'Photoplug';
	var $priority = 70;
	var $apply_rendering = 'lazy';
	var $group = 'rendering';
	var $short_desc;
	var $long_desc;
	var $author="Brinley Ang";
	var $version = '1.0';
	var $number_of_installs = 1;
	var $search;
	var $replace;
	
	/**
	 * Init
	 */
	function PluginInit( & $params )
	{
		$this->short_desc = T_('Photoplug plugin');
		$this->long_desc = T_('This is a simple photo plugin for embedding gallery slideshows from flickr and picasa. Please use the admin toolbar to see the code syntax.');
		
		$this->search = array(	'#\[flickr](.+?)\[/flickr]#s',
			'#\[picasa](.+?)\[/picasa]#s'
			);
			
		$this->search = array(
			'/\[flickr\](.+?):(.+?):(.+?):(.+?)\[\/flickr\]/e',
			'/\[picasa\](.+?):(.+?):(.+?)\[\/picasa\]/e',
		);

		$this->replace = array(
			'$this->generate_flickr( str_replace("\\\'", "\'", "$1"), str_replace("\\\'", "\'", "$2"), str_replace("\\\'", "\'", "$3"), str_replace("\\\'", "\'", "$4"))',
			'$this->generate_picasa( str_replace("\\\'", "\'", "$1"), str_replace("\\\'", "\'", "$2"), str_replace("\\\'", "\'", "$3"))',
		);
		return true;
	}


	/**
	 * Perform rendering
	 *
	 * @todo add more photo sites, anyone...
	 *
	 * @see Plugin::RenderItemAsHtml()
	 */
	function RenderItemAsHtml( & $params )
	{
		$content = & $params['data'];
		$content = preg_replace( $this->search, $this->replace, $content);
		return true;
	}

	function generate_picasa($sUsername,$iAlbumid,$iSize)
	{
		// TODO: Validate parameters
		$iWidth=600;
		$iHeight=400; 

		if (isset($iSize))
		{
			$arrSize=explode("x",$iSize);
			$iWidth=intval($arrSize[0]);
			$iHeight=intval($arrSize[1]); 
		} 
		$result='<div><embed type="application/x-shockwave-flash" src="http://picasaweb.google.com/s/c/bin/slideshow.swf" width="'.$iWidth.'" height="'.$iHeight.'" flashvars="host=picasaweb.google.com&RGB=0x000000&feed=http%3A%2F%2Fpicasaweb.google.com%2Fdata%2Ffeed%2Fapi%2Fuser%2F'.$sUsername.'%2Falbumid%2F'.$iAlbumid.'%3Fkind%3Dphoto%26alt%3Drss" pluginspage="http://www.macromedia.com/go/getflashplayer"></embed></div>';
		return $result;
	}

	function generate_flickr($sUserId,$sTag,$iSize,$iSetId)
	{
		// TODO: Validate parameters
		$iWidth=500;
		$iHeight=500; 

		if (isset($iSize))
		{
			$arrSize=explode("x",$iSize);
			$iWidth=intval($arrSize[0]);
			$iHeight=intval($arrSize[1]); 
		}

		$result='<div><object type="text/html" data="http://www.flickr.com/slideShow/index.gne?user_id='.$sUserId.'&tags='.$sTag.'&set_id='.$iSetId.'" width="'.$iWidth.'" height="'.$iHeight.'"></object></div>';
		return $result;
	}

	/**
	 * Perform rendering for XML feeds
	 *
	 * @see Plugin::RenderItemAsXml()
	 */
	function RenderItemAsXml( & $params )
	{
		$this->RenderItemAsHtml( $params );
		return true;
	}

	function ItemApplyAsRenderer( & $params )
	{
		foreach( $this->search as $search )
		{
			if( preg_match( $search, $params['Item']->content ) )
			{
				return true;
			}
		}
		return false;
	}

	function PrependItemInsertTransact( & $params )
	{
		$match = false;
		foreach ($this->search as $item) {
			if( preg_match( $item, $params['Item']->content ) )
			{
				$match = true;
				break;
			}
		}
		if ($match) { // there's our code in there
			$params['Item']->add_renderer( $this->code );
		}
		else
		{
			$params['Item']->remove_renderer( $this->code );
		}
	}
	
	/**
	 * We detect, if our renderer gets used, by looking at the content and add our renderer code, if it gets used.
	 * @deprecated since 1.9 by ItemApplyAsRenderer()
	 */
	function PrependItemUpdateTransact( & $params )
	{
		$this->PrependItemInsertTransact( $params );
	}

	/**
	 * Add the renderer also for previews.
	 * @deprecated since 1.9 by ItemApplyAsRenderer()
	 */
	function AppendItemPreviewTransact( & $params )
	{
		$this->PrependItemInsertTransact( $params );
	}
	
	/**
	 * Display a toolbar in admin
	 *
	 * @param array Associative array of parameters
	 * @return boolean did we display a toolbar?
	 */
	function AdminDisplayToolbar( & $params )
	{
		if( $params['edit_layout'] == 'simple' )
		{	// This is too complex for simple mode, don't display it:
			return false;
		}

		echo '<div class="edit_toolbar">';
		echo T_('Photo').': ';
		echo '<input type="button" id="photo_flickr" title="'.T_('Insert flickr photo gallery').'" class="quicktags" onclick="photoTag(\'flickr\');" value="'.T_('Flickr').'" />';
		echo '<input type="button" id="photo_picasa" title="'.T_('Insert Google picasa gallary').'" class="quicktags" onclick="photoTag(\'picasa\');" value="'.T_('Picasa').'" />';
		echo '</div>';

		?>
		<script type="text/javascript">
			//<![CDATA[
			function nullCheck(i)
			{
				if(!i)return " ";
				else return i;			
			}
			
			function photoTag( tag )
			{
				switch (tag)
				{
					case "flickr":
						var iUserId = prompt('<?php echo TS_('Enter flickr user ID which can be retrieved from http://idgettr.com/') ?>:', '' );
						var sTag = prompt('<?php echo TS_('Enter Image tag that belong to previously specified ID') ?> :', '' );
						var iSize = prompt('<?php echo TS_('Enter the dimensions of the album. eg. 500x500') ?> :', '500x500' );
						var iSetId = prompt('<?php echo TS_('Enter Image Set Id') ?>:', '' );
						tag = '[flickr]'+nullCheck(iUserId)+':'+nullCheck(sTag)+':'+nullCheck(iSize)+':'+nullCheck(iSetId)+'[/flickr]';
						break;
					case "picasa":
						var iUserId = prompt('<?php echo TS_('Enter picasa username of the owner of the picasa photo album') ?> :', '' );
						var iAlbumId = prompt('<?php echo TS_('Enter album id of the picasa album') ?> :', '' );
						var iSize = prompt('<?php echo TS_('Enter the dimensions of the album. eg. 800x533, 600x400, 400x267, 288x192, 144x96') ?> :', '600x400' );
						tag = '[picasa]'+nullCheck(iUserId)+':'+nullCheck(iAlbumId)+':'+nullCheck(iSize)+'[/picasa]';
						break;
					default:
						return;
				}
				textarea_wrap_selection( b2evoCanvas, tag, '', 1 );
			}
			//]]>
		</script>
		<?php
		return true;
	}
}

?>